@@ -108,9 +108,15 @@
     Updated by      Richard Gooch   9-DEC-1999: Support compiling with 2.2.x
   kernels.
 
-    Last updated by Richard Gooch   15-DEC-1999: Added compatibility entries
+    Updated by      Richard Gooch   15-DEC-1999: Added compatibility entries
   for miscellaneous character devices.
 
+    Updated by      Richard Gooch   17-DEC-1999: Do not grab event queue when
+  just setting devfs debug mask.
+
+    Last updated by Richard Gooch   20-DEC-1999: Swap pathname and action
+  fields in config file.
+
 
 */
 #include <unistd.h>
@@ -144,7 +150,7 @@
 #endif
 
 
-#define VERSION "1.2.14"
+#define VERSION "1.3.0"
 #define CONFIG_FILE "/etc/devfsd.conf"
 #define MAX_ARGS (6 + 1)
 
@@ -324,7 +330,7 @@ int main (int argc, char **argv)
 	fprintf (stderr, "Error getting protocol revision\t%s\n", ERRSTRING);
 	exit (1);
     }
-    setup_initial_entries ();
+    if (!debug_devfs) setup_initial_entries ();
     if (!print_version && !debug_protocol && !debug_devfs)
     {
 	if (stat (CONFIG_FILE, &statbuf) != 0)
@@ -358,12 +364,6 @@ int main (int argc, char **argv)
 	}
     }
     if (print_version) exit (0);
-    /*  Tell kernel we are special (i.e. we get to see hidden entries)  */
-    if (ioctl (fd, DEVFSDIOC_SET_EVENT_MASK, 0) != 0)
-    {
-	fprintf (stderr, "Error setting event mask\t%s\n", ERRSTRING);
-	exit (1);
-    }
     if (debug_devfs)
     {
 	if (ioctl (fd, DEVFSDIOC_SET_DEBUG_MASK, &devfs_debug_mask) != 0)
@@ -373,6 +373,12 @@ int main (int argc, char **argv)
 	}
 	exit (0);
     }
+    /*  Tell kernel we are special (i.e. we get to see hidden entries)  */
+    if (ioctl (fd, DEVFSDIOC_SET_EVENT_MASK, 0) != 0)
+    {
+	fprintf (stderr, "Error setting event mask\t%s\n", ERRSTRING);
+	exit (1);
+    }
     if (debug_protocol) do_debug (fd);
     sigemptyset (&new_action.sa_mask);
     new_action.sa_flags = 0;
@@ -475,7 +481,7 @@ static void read_config (CONST char *filename, flag optional,
 	if (line[0] == '#') continue;
 	for (count = 0; count < MAX_ARGS; ++count) p[count][0] = '\0';
 	num_args = sscanf (line, "%s %s %s %s %s %s %s %s %s %s",
-			   when, what, name, p[0], p[1], p[2], p[3],
+			   when, name, what, p[0], p[1], p[2], p[3],
 			   p[4], p[5], p[6]);
 	if (strcasecmp (when, "CLEAR_CONFIG") == 0)
 	{
